@@ -1,10 +1,14 @@
 from datetime import datetime
 import csv
+import feedparser
 from post import Post
 
 
 class Home():
     def __init__(self):
+        self.feed = feedparser.parse('http://www.facebook.com/feeds/page.php?format=atom10&id=121855461256134')
+        print(self.feed['feed']['title'])
+
         print(
             '\nWelcome to SIGACTor, currently available '
             'for the Syria team and reading posts from the '
